#!/usr/bin/gnuplot

# Kretke & Lin (2012), Fig. 1

p_isothermal(q) = 0.85 - 0.9*q
p_adiabatic(q) = 0.26 + 1.21*q

set term png small
set out "pq.png"

set xl "q = d ln T/d ln r []"
set yl "p = d ln Sigma/d ln r []"
set cbl "r [au]"

load "config.plt"
r(i) = Rmin+(Rmax-Rmin)*i/Nsec/Nr

set xr [-3:1]
set yr [-3:2]
set cbr [0.2:2.0]

set xzeroaxis
set grid noxtics noytics front
set colorbox

set label "outward migration"             at 0.0,1.25 front
set label "(potential) outward migration" at graph 0.05,first -0.3 front
set label "inward migration"              at 0.0,-2.7 front

p \
  p_adiabatic(x)  not w filledcurves x2 lc '#ffffcc',\
  p_isothermal(x) not w filledcurves x2 lt 5,\
  p_isothermal(x) t "Paardekooper etal. (2010), isothermal, saturated" w l lt 0,\
  p_adiabatic(x)  t "adiabatic, unsaturated" w l lt 4,\
  "<./used_rad.awk used_rad.dat paste.tmp | ./pq.awk" u 3:2:1 not w l lc palette z lw 2,\
  "<./used_rad.awk used_rad.dat paste.tmp | ./pq.awk | awk '!/\?/'" u 3:2:(sprintf("%.2f",$1)) not w labels

